@@ -20,12 +20,18 @@
 http://developer.gnome.org/doc/API/gnome-vfs/
 """
 import Sword
-from gnome import gnomevfs
+try:
+    from gnome import gnomevfs
+except:
+    import gnomevfs
 import os
 import tarfile
 import re
 import osso
-from gnome import gconf
+try:
+    from gnome import gconf
+except:
+    import gconf
 import sys
 
 
@@ -43,6 +49,8 @@ def debug(snt):
     
 def get_manager(*args):
     data_path = get_data_path()
+    if data_path:
+        os.environ["SWORD_PATH"]=data_path
     mgr = Sword.SWMgr(*args)
     if data_path:
         mgr.prefixPath = data_path
@@ -98,7 +106,7 @@ class InstallMgr:
     of remote Sword modules.
     """
 
-    def __init__(self,dataPath,location='ftp://crosswire.org/pub/sword/raw',\
+    def __init__(self,dataPath,location='ftp://64.140.154.250/pub/sword/raw',\
                  osso_context=False):
         self.mgr=get_manager()
         self.rep_location=location
@@ -347,7 +355,7 @@ class InstallMgr:
             return False
         except :
             debug("Something is borked")
-
+            raise
             return False
 
 
